summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/rawconverter/rawdecodingiface.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kipi-plugins/rawconverter/rawdecodingiface.cpp')
-rw-r--r--kipi-plugins/rawconverter/rawdecodingiface.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kipi-plugins/rawconverter/rawdecodingiface.cpp b/kipi-plugins/rawconverter/rawdecodingiface.cpp
index d9d8e5f..c2653ee 100644
--- a/kipi-plugins/rawconverter/rawdecodingiface.cpp
+++ b/kipi-plugins/rawconverter/rawdecodingiface.cpp
@@ -10,7 +10,7 @@
* Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
*
* NOTE: Do not use kdDebug() in this implementation because
* it will be multithreaded. Use qDebug() instead.
* See B.K.O #133026 for details.
*
* This program is free software; you can redistribute it
@@ -215,7 +215,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
if (!f)
{
- qDebug("Failed to open JPEG file for writing");
+ tqDebug("Failed to open JPEG file for writing");
return false;
}
@@ -276,7 +276,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
if (!f)
{
- qDebug("Failed to open PNG file for writing");
+ tqDebug("Failed to open PNG file for writing");
return false;
}
@@ -353,7 +353,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
if (!tif)
{
- qDebug("Failed to open TIFF file for writing");
+ tqDebug("Failed to open TIFF file for writing");
return false;
}
@@ -430,7 +430,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
if (!bufThumb)
{
- qDebug("Cannot allocate memory buffer for TIFF thumbnail.");
+ tqDebug("Cannot allocate memory buffer for TIFF thumbnail.");
TIFFClose(tif);
return false;
}
@@ -451,7 +451,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
if (!TIFFWriteScanline(tif, bufThumb, y, 0))
{
- qDebug("Cannot write TIFF thumbnail to target file.");
+ tqDebug("Cannot write TIFF thumbnail to target file.");
_TIFFfree(bufThumb);
TIFFClose(tif);
return false;
@@ -473,7 +473,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
FILE* f = fopen(TQFile::encodeName(destPath), "wb");
if (!f)
{
- qDebug("Failed to open ppm file for writing");
+ tqDebug("Failed to open ppm file for writing");
return false;
}
@@ -484,7 +484,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
}
default:
{
- qDebug("Invalid output file format");
+ tqDebug("Invalid output file format");
return false;
}
}
@@ -515,7 +515,7 @@ void RawDecodingIface::writeRawProfile(png_struct *ping, png_info *ping_info, ch
const uchar hex[16] = {'0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f'};
- qDebug("Writing Raw profile: type=%s, length=%i", profile_type, (int)length);
+ tqDebug("Writing Raw profile: type=%s, length=%i", profile_type, (int)length);
text = (png_textp) png_malloc(ping, (png_uint_32) sizeof(png_text));
description_length = strlen((const char *) profile_type);
@@ -10,7 +10,7 @@
*
* NOTE: Do not use kdDebug() in this implementation because
- * it will be multithreaded. Use qDebug() instead.
+ * it will be multithreaded. Use tqDebug() instead.
* See B.K.O #133026 for details.
*